package com.xtd.project.assets.mapper;

import java.util.List;
import com.xtd.project.assets.domain.DbAssetsStockIn;
import com.xtd.project.assets.domain.DbAssetsStockInForm;

/**
 * 资产入库Mapper接口
 *
 * @author xtd
 * @date 2020-04-09
 */
public interface DbAssetsStockInMapper
{
    /**
     * 查询资产入库
     *
     * @param aId 资产入库ID
     * @return 资产入库
     */
    public DbAssetsStockIn selectDbAssetsStockInById(Long aId);

    /**
     * 查询资产入库列表
     *
     * @param dbAssetsStockIn 资产入库
     * @return 资产入库集合
     */
    public List<DbAssetsStockIn> selectDbAssetsStockInList(DbAssetsStockIn dbAssetsStockIn);

    /**
     * 新增资产入库
     *
     * @param dbAssetsStockIn 资产入库
     * @return 结果
     */
    public int insertDbAssetsStockIn(DbAssetsStockIn dbAssetsStockIn);

    /**
     * 修改资产入库
     *
     * @param dbAssetsStockIn 资产入库
     * @return 结果
     */
    public int updateDbAssetsStockIn(DbAssetsStockIn dbAssetsStockIn);

    /**
     * 删除资产入库
     *
     * @param aId 资产入库ID
     * @return 结果
     */
    public int deleteDbAssetsStockInById(Long aId);

    /**
     * 批量删除资产入库
     *
     * @param aIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteDbAssetsStockInByIds(Long[] aIds);

    DbAssetsStockInForm form(Long aId);
}
